<?php
/* Copyright (C) 2021 SuperAdmin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * \file    ichosting/class/actions_ichosting.class.php
 * \ingroup ichosting
 * \brief   Example hook overload.
 *
 * Put detailed description here.
 */

/**
 * Class ActionsIchosting
 */

dol_include_once('/ichosting/lib/ichosting.lib.php');
class ActionsIchosting
{
	/**
	 * @var DoliDB Database handler.
	 */
	public $db;

	/**
	 * @var string Error code (or message)
	 */
	public $error = '';

	/**
	 * @var array Errors
	 */
	public $errors = array();


	/**
	 * @var array Hook results. Propagated to $hookmanager->resArray for later reuse
	 */
	public $results = array();

	/**
	 * @var string String displayed by executeHook() immediately after return
	 */
	public $resprints;


	/**
	 * Constructor
	 *
	 *  @param		DoliDB		$db      Database handler
	 */
	public function __construct($db)
	{
		$this->db = $db;
	}


	/**
	 * Execute action
	 *
	 * @param	array			$parameters		Array of parameters
	 * @param	CommonObject    $object         The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
	 * @param	string			$action      	'add', 'update', 'view'
	 * @return	int         					<0 if KO,
	 *                           				=0 if OK but we want to process standard actions too,
	 *                            				>0 if OK and we want to replace standard actions.
	 */
	public function getNomUrl($parameters, &$object, &$action)
	{
		global $db, $langs, $conf, $user;
		$this->resprints = '';
		return 0;
	}

    public function printFieldPreListTitle($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $user, $langs;
        //Hide deploy and develop tabs on modules administration page for light administrators.
            if(isAdminLight($user)) {
                print '<script type="text/javascript">
                        $("#deploy").remove();
                        $("#develop").remove();
                   </script>';
            }

    }

    public function printLeftBlock($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $user, $langs;
        $error = 0; // Error counter
        if(isAdminLight($user)){
            print '<script type="text/javascript">
                    $( ".menu_contenu_admin_security_other" ).remove();
                    $( ".menu_contenu_admin_sms" ).remove();
                    $( ".menu_contenu_admin_const" ).remove();
                  //  $( ".blockvmenupair").children("div").hide();
                   // $( ".blockvmenupair .menu_titre").show();
                    //$( ".menu_contenu_admin_tools_dolibarr_export").show();
                    //$( ".menu_contenu_admin_system_about").show();                             
                    $( ".menu_contenu_admin_system_dolibarr").remove();                             
                    $( ".menu_contenu_admin_system_browser").remove(); 
                    $( ".menu_contenu_admin_system_os").remove(); 
                    $( ".menu_contenu_admin_system_phpinfo").remove();
                    $( ".menu_contenu_admin_system_web").remove();
                    $( ".menu_contenu_admin_system_database").remove();
                    $( ".menu_contenu_admin_system_perf").remove();
                    $( ".menu_contenu_admin_system_security").remove();
                    $( ".menu_contenu_admin_tools_dolibarr_import").remove();
                    $( ".menu_contenu_admin_tools_update").remove();
                    $( ".menu_contenu_admin_tools_purge").remove();
                    $( ".menu_contenu_admin_tools_listevents").remove();
                    $( ".menu_contenu_admin_tools_listsessions").remove();
                    $( ".menu_contenu_product_admin_product_tools").remove();
                    $( ".menu_contenu_modulebuilder_index").remove();
                    $( ".menu_contenu_cron_list").remove();           
                    </script>';
        }
        if (!$error) {
            $this->results = array('myreturn' => 999);
            return 0; // or return 1 to replace standard code
        } else {
            $this->errors[] = 'Error message';
            return -1;
        }
    }

	public function addMoreActionsButtons($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $user, $langs, $canreaduser;

		$error = 0; // Error counter

//		print_r($parameters); print_r($object); echo "action: " . $action;
		if (in_array($parameters['currentcontext'], array('usercard'))) {
            if(isAdminLight($user) && $object->admin && !isAdminLight($object)){
                print '<script type="text/javascript">';
                print '$(".tabsAction").remove();';
                print '</script>';
            }
		    // Do what you want here...
			// You can for example call global vars like $fieldstosearchall to overwrite them, or update database depending on $action and $_POST values.
		}

		if (!$error) {
			$this->results = array('myreturn' => 999);
			$this->resprints = 'A text to show';
			return 0; // or return 1 to replace standard code
		} else {
			$this->errors[] = 'Error message';
			return -1;
		}
	}
	

	public function formObjectOptions($parameters, &$object, &$action, $hookmanager)
	{
		global $conf, $user, $langs;
		$error = 0; // Error counter
        //print_r($parameters); print_r($object); echo "action: " . $action;

		if (in_array($parameters['currentcontext'], array('usercard')) || in_array('usercard', explode(':',$parameters['context']))) {

            if(isAdminLight($user) && $object->admin && !isAdminLight($object)){
                print '<script type="text/javascript">
                        $( document ).ready(function() {
                           $(".tabs").children().hide();
                           $(".tabs").children().eq(1).show();
                           $(".tabsAction").remove();                    
                       });
                       </script>';
            }
            if($action == "" && isAdminLight($object)){
                print '<script type="text/javascript">
                      $( document ).ready(function() {
                            $(".fichehalfleft tbody").eq(0).prepend("<td><span style=\'font-style: italic; font-weight: bold;\'>Admin light</span></td>");                         
                       });
                </script>';
            }

		    if($action == "create" || $action == "edit"){
                print '<script type="text/javascript">';
                    print '$("#admin").append(new Option("Admin Light","2"));';
                    print '$("#admin").css("width", "105px");';
                    //super user must not be able to create an admin user, for obvious reasons
                    if(isAdminLight($user)){
                        print '$("#admin option[value=1]").remove();';
                        print '$("#admin option[value=2]").remove();';
                    }
                print '</script>';
            }

            if($action == "edit"){
                 print '<script type="text/javascript">
                         </script>';
                //light admins must not be able to modify any of the admin properties
                if(isAdminLight($object)){
                     print '<script type="text/javascript"> 
                                 $("#admin option[value=2]").attr("selected","selected");
                                 $("input[name=\"admin\"]").val(2);
                             </script>';

                }
                if(isAdminLight($user) && $object->admin && !isAdminLight($object)){
                    print '<script type="text/javascript">
                            $(".fiche").remove();
                            </script>';
                }
            };
		   // do something only for the context 'somecontext1' or 'somecontext2'
			// Do what you want here...
			// You can for example call global vars like $fieldstosearchall to overwrite them, or update database depending on $action and $_POST values.
		}

		/*if (!$error) {
			$this->results = array('myreturn' => 999);
			$this->resprints = 'A text to show';
			return 0; // or return 1 to replace standard code
		} else {
			$this->errors[] = 'Error message';
			return -1;
		}*/
	}

    public function printSearchForm($parameters, &$object, &$action, $hookmanager)
    {
        global $conf, $user;

        $error = 0; // Error counter
         // if dropdown menu module is enabled (exit function)
        $users = array("master");
        if(!empty($conf->global->IC_HOSTING_USER_SWITCHER_USERS)){
            $users = array_merge($users,explode(",",$conf->global->IC_HOSTING_USER_SWITCHER_USERS));
        }
        if((in_array($user->login, $users) || ( isset($_SESSION["dol_main_login"]) && $_SESSION["dol_main_login"] != "" ))) $this->resprints = $this->getUsersListHTML();
        if (! $error)
        {
            return 0; // or return 1 to replace standard code
        }
        else
        {
            return -1;
        }
    }

    /**
     * Overloading the printCommonFooter function
     *
     * @param   array()         $parameters     Hook metadatas (context, etc...)
     * @param   CommonObject    &$object        The object to process (an invoice if you are in invoice module, a propale in propale's module, etc...)
     * @param   string          &$action        Current action (if set). Generally create or edit or null
     * @param   HookManager     $hookmanager    Hook manager propagated to allow calling another hook
     * @return  int                             < 0 on error, 0 on success, 1 to replace standard code
     */
    public function printCommonFooter($parameters, &$obj, &$action, $hookmanager)
    {
        global $langs, $user, $conf;

        $error = 0; // Error counter
        $context = explode(':', $parameters['context']);

        if ((in_array('main', $context) || in_array('login', $context)) && ! empty($conf->dropdownmenu->enabled) && ((isset($_SESSION['dol_main_login']) && ! empty($_SESSION['dol_main_login']))))
        {
            $langs->load('userswitcher@userswitcher');
            echo '<div id="userswitcher-dialog" title="'.$langs->trans('UserSwitcher').'" style="display: none;">';

            echo $this->getUsersListHTML('100%');
            echo '</div>';

            echo '<script type="text/javascript">
			$(document).ready(function () {
				$("#userswitcher-button").click(function(e){
					$("#userswitcher-dialog").show().dialog({
						width: 400,
						resizable: false,
						modal: true,
						buttons: {
							"'.$langs->transnoentities('CloseDialog').'": function() {
								$("#userswitcher-dialog").dialog("close");
							}
						}
					});
					e.preventDefault();
				});
			});
			</script>' . "\n";
        }

        if (! $error)
        {
            return 0; // or return 1 to replace standard code
        }
        else
        {
            $this->errors[] = 'Could not render userswitcher dialog';
            return -1;
        }
    }

    /**
     * Return users list html
     *
     * @return string users list html
     */
    private function getUsersListHTML($width = '200px')
    {
        global $user, $conf, $db, $langs;

        // Get users
        $main_login = isset($_SESSION['dol_main_login']) ? $_SESSION['dol_main_login'] : $user->login;
        $fullNameMode = 0; //Lastname + firstname
        $query = 'SELECT rowid, lastname, firstname, login, photo FROM '.MAIN_DB_PREFIX.'user WHERE statut = 1 AND entity IN(0, '.$conf->entity.')';
        if (! empty($conf->global->USER_SWITCHER_HIDDEN_USERS))
        {
            $hidden_users = explode(',', $conf->global->USER_SWITCHER_HIDDEN_USERS);
            foreach ($hidden_users as $key => $login) {
                if ($login == $main_login) {
                    unset($hidden_users[$key]);
                }
            }
            $query.= " AND login NOT IN ('".join("','", $hidden_users)."')";
        }
        if(empty($conf->global->MAIN_FIRSTNAME_NAME_POSITION)) {
            $query.= " ORDER BY firstname ASC";
            $fullNameMode = 1; //firstname + lastname
        } else {
            $query.= " ORDER BY lastname ASC";
        }

        $result = $db->query($query);
        $users = array();
        $userstatic = new User($db);

        if ($result)
        {
            $rows_count = $db->num_rows($result);
            $row_num = 0;

            while($row_num < $rows_count) {
                $obj = $db->fetch_object($result);
                $userstatic->id = $obj->rowid;
                $userstatic->lastname = $obj->lastname;
                $userstatic->firstname = $obj->firstname;
                $userstatic->photo = $obj->photo;
                if (! empty($obj->photo)) {
                    $picto = Form::showphoto('userphoto', $userstatic, 0, 0, 0, 'userphoto', 'mini', 0, 1);
                }
                else {
                    $picto = img_object('', 'user', '', 0, 0, 0);
                }
                $fullname = $userstatic->getFullName($langs, $fullNameMode);
                $users[$obj->login] = array(
                    'image'    => $picto,
                    'fullname' => $fullname
                );
                $row_num++;
            }
        }

        // Show users
        $form = new Form($db);
        $html = '<div style="margin-top: 12px;">';
        //$html.= $form->select_dolusers($user->id, 'currentuserid', 0, null, 0, '', '', 0, 0, 0, 'AND statut = 1');
        $html.= '<select id="currentuserid" style="width: '.$width.'">';
        foreach ($users as $key => $value) {
            $html.= '<option value="'.$key.'" data-image="'.htmlentities($value['image']).'"'.($key == $_SESSION['dol_login'] ? ' selected' : '').'>'.$value['fullname'].'</option>';
        }
        $html.= '</select>';
        $html.= '<script type="text/javascript">
		$(document).ready(function () {
			$("#currentuserid").select2({
				dir: "ltr",
				width: "resolve", /* off or resolve */
				minimumInputLength: 0,
				templateResult: addUserPic,
				templateSelection: addUserPic
			});
			function addUserPic(option) {
				if (!option.id) {
					return option.text;
				}
				var optionimage = $(option.element).data("image"); 
				if(!optionimage){
					return option.text;
				} else {
					var $opt = $("<span>" + optionimage + " " + $(option.element).text() + "</span>");
					return $opt;
				}
			};
			$("#currentuserid").change(function() {
				$(location).attr("href", "'.dol_buildpath('ichosting/set_user.php', 1).'?backtopage='.urlencode($_SERVER['PHP_SELF'].'?'.$_SERVER['QUERY_STRING']).'&login=" + $(this).val());
			});
		});
		</script>' . "\n";

        $html.= '</div>';
        //$html .= $conf->global->IC_HOSTING_USER_SWITCHER_USERS;
        return $html;
    }

	/**

	/* Add here any other hooked methods... */
}
